@@ -138,6 +138,12 @@ class OvnProviderDriver(driver_base.ProviderDriver):
 
     def listener_create(self, listener):
         self._check_for_supported_protocols(listener.protocol)
+        # TODO(haleyb): add support for this
+        if not isinstance(listener.allowed_cidrs, o_datamodels.UnsetType):
+            msg = _('OVN provider does not support allowed_cidrs option')
+            raise driver_exceptions.UnsupportedOptionError(
+                user_fault_string=msg,
+                operator_fault_string=msg)
         admin_state_up = listener.admin_state_up
         if isinstance(admin_state_up, o_datamodels.UnsetType):
             admin_state_up = True
@@ -161,6 +167,13 @@ class OvnProviderDriver(driver_base.ProviderDriver):
         self._ovn_helper.add_request(request)
 
     def listener_update(self, old_listener, new_listener):
+        # TODO(haleyb): add support for this
+        if not isinstance(new_listener.allowed_cidrs, o_datamodels.UnsetType):
+            msg = _('OVN provider does not support allowed_cidrs option')
+            raise driver_exceptions.UnsupportedOptionError(
+                user_fault_string=msg,
+                operator_fault_string=msg)
+
         request_info = {'id': new_listener.listener_id,
                         'loadbalancer_id': old_listener.loadbalancer_id,
                         'protocol': old_listener.protocol,
@@ -273,23 +286,9 @@ class OvnProviderDriver(driver_base.ProviderDriver):
                    'info': request_info}
         self._ovn_helper.add_request(request)
 
-    def member_batch_update(self, members):
-        # Note(rbanerje): all members belong to the same pool.
+    def member_batch_update(self, pool_id, members):
         request_list = []
         skipped_members = []
-        pool_id = None
-        try:
-            pool_id = members[0].pool_id
-        except IndexError:
-            msg = _('No member information has been passed')
-            raise driver_exceptions.UnsupportedOptionError(
-                user_fault_string=msg,
-                operator_fault_string=msg)
-        except AttributeError:
-            msg = _('Member does not have proper pool information')
-            raise driver_exceptions.UnsupportedOptionError(
-                user_fault_string=msg,
-                operator_fault_string=msg)
         pool_key, ovn_lb = self._ovn_helper._find_ovn_lb_by_pool_id(pool_id)
         external_ids = copy.deepcopy(ovn_lb.external_ids)
         existing_members = external_ids[pool_key].split(',')
