@@ -42,6 +42,9 @@ tests_imports_from2 = re.compile(
     r"\bfrom[\s]+ovn_octavia_provider[\s]+import[\s]+tests\b")
 no_line_continuation_backslash_re = re.compile(r'.*(\\)\n')
 
+import_mock = re.compile(r"\bimport[\s]+mock\b")
+import_from_mock = re.compile(r"\bfrom[\s]+mock[\s]+import\b")
+
 
 @core.flake8ext
 def check_assert_called_once_with(logical_line, filename):
@@ -162,3 +165,19 @@ def check_python3_no_filter(logical_line):
 
     if filter_match.match(logical_line):
         yield(0, msg)
+
+
+@core.flake8ext
+def check_no_import_mock(logical_line, filename, noqa):
+    """N347 - Test code must not import mock library."""
+    msg = ("N347: Test code must not import mock library")
+
+    if noqa:
+        return
+
+    if 'ovn_octavia_provider/tests/' not in filename:
+        return
+
+    for regex in import_mock, import_from_mock:
+        if re.match(regex, logical_line):
+            yield(0, msg)
